# pyfoot

Pyfoot is a high-level library for writing simple 2d games.
It is based upon the Python library [pygame](https://github.com/pygame/pygame "Pygame Github") and was inspired by the java libary [Greenfoot](https://www.greenfoot.org/door "Greenfoot Homepage").

### Installing

Simply pip install the library

```
pip install pyfoot
```

You can create a sample project via the command line

```
python -m pyfoot init ProjectName
```


## License

This project is licensed under the GNU License - see the [LICENSE.md](LICENSE.md) file for details
